# coding: utf-8

# flake8: noqa
"""
    Gopad OpenAPI

    API definition for Gopad, Etherpad for markdown with go

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: gopad@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from gopad.models.auth_login import AuthLogin
from gopad.models.auth_token import AuthToken
from gopad.models.auth_verify import AuthVerify
from gopad.models.notification import Notification
from gopad.models.profile import Profile
from gopad.models.team import Team
from gopad.models.team_user_params import TeamUserParams
from gopad.models.team_users import TeamUsers
from gopad.models.teams import Teams
from gopad.models.user import User
from gopad.models.user_auth import UserAuth
from gopad.models.user_team import UserTeam
from gopad.models.user_team_params import UserTeamParams
from gopad.models.user_teams import UserTeams
from gopad.models.users import Users
from gopad.models.validation import Validation
